@@ -816,9 +816,9 @@ void Settings::legacyLoad(const QString &path) {
 
 	LOADENUM(noiseCancelMode, "audio/noiseCancelMode");
 
-#ifndef USE_RNNOISE
+#ifndef USE_RENAMENOISE
 	if (noiseCancelMode == NoiseCancelRNN || noiseCancelMode == NoiseCancelBoth) {
-		// Use Speex instead as this Mumble build was built without support for RNNoise
+		// Use Speex instead as this Mumble build was built without support for ReNameNoise
 		noiseCancelMode = NoiseCancelSpeex;
 	}
 #endif
